==> haskell-servant-swagger-1.2.1-50.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-swagger
version:              1.2.1
visibility:           public
id:                   servant-swagger-1.2.1-HuEKp6PPCYHwfvovMsq2w
key:                  servant-swagger-1.2.1-HuEKp6PPCYHwfvovMsq2w
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:
    https://github.com/haskell-servant/servant/tree/master/servant-swagger#readme

synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  1b3d89ae4e04f0ce1f6eab9195b621e9
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-swagger-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-swagger
hs-libraries:         HSservant-swagger-1.2.1-HuEKp6PPCYHwfvovMsq2w
depends:
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy
    aeson-pretty-0.8.10-EqoqZyHsOVOICKhlMxDJzf base-4.17.2.1
    base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp bytestring-0.11.5.3
    hspec-2.10.9-8PqvxiZVgrL4DvXVyNhtnS
    http-media-0.8.1.1-BFy2hdXmGfW3j30QAUlbGd
    insert-ordered-containers-0.2.5.3-CzTEc9M1v8M54RshVLjyaa
    lens-5.2.3-7k2QwsHyLcVK6NgbwpIzej
    servant-0.20.2-6CzPpRSI87CH8XRejJaoKb
    singleton-bool-0.1.7-9GTE90UheKZ915n4jKALiB
    swagger2-2.8.9-DkH7C8XTzVL797EZB04h75 text-2.0.2
    unordered-containers-0.2.20-WenrpHtwHKIVom5hXYF7C

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.2-30-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 servant-swagger
version:              1.2
visibility:           public
id:                   servant-swagger-1.2-6CpXD0DKYdwAkyTy6OUn7S
key:                  servant-swagger-1.2-6CpXD0DKYdwAkyTy6OUn7S
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:
    https://github.com/haskell-servant/servant/tree/master/servant-swagger#readme

synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  9f70d9d1c7324972aa37b1db79d21d76
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-9.2.8/site-local/servant-swagger-1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/servant-swagger-1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-swagger
hs-libraries:         HSservant-swagger-1.2-6CpXD0DKYdwAkyTy6OUn7S
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    aeson-pretty-0.8.10-3gMGTHlvRlNFcX72WIXlCa base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd bytestring-0.11.4.0
    hspec-2.10.9-KuS4B4SgPwm179O4lsuAOc
    http-media-0.8.1.1-A7M9nIzO3PC4x2uGSYBBks
    insert-ordered-containers-0.2.5.3-F0ZRi7Oq5dT7vHaahaTzjt
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0
    servant-0.20.2-Ao9FJb1nrGg31HF8azeLuw
    singleton-bool-0.1.7-2tDFkbjFLK6CMTjgJvZrRz
    swagger2-2.8.9-C4px5TiNFyPHSbCgWavwfg text-1.2.5.0
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
